@@ -106,6 +106,7 @@ class TripleoInventory(object):
             self.ansible_ssh_user = ansible_ssh_user
             self.plan_name = plan_name
         self.stack_outputs = StackOutputs(self.plan_name, self.hclient)
+        self.hostvars = {}
 
     @staticmethod
     def get_roles_by_service(enabled_services):
@@ -151,9 +152,10 @@ class TripleoInventory(object):
 
     def list(self):
         ret = OrderedDict({
-            'undercloud': {
-                'hosts': self._hosts(['localhost']),
+            'Undercloud': {
+                'hosts': self._hosts(['undercloud']),
                 'vars': {
+                    'ansible_host': 'localhost',
                     'ansible_connection': 'local',
                     # see https://github.com/ansible/ansible/issues/41808
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
@@ -172,75 +174,83 @@ class TripleoInventory(object):
         if self.session:
             swift_url = self.session.get_endpoint(service_type='object-store',
                                                   interface='public')
-        ret['undercloud']['vars']['undercloud_swift_url'] = swift_url
+        ret['Undercloud']['vars']['undercloud_swift_url'] = swift_url
 
         keystone_url = self.stack_outputs.get('KeystoneURL')
         if keystone_url:
-            ret['undercloud']['vars']['overcloud_keystone_url'] = keystone_url
+            ret['Undercloud']['vars']['overcloud_keystone_url'] = keystone_url
         admin_password = self.get_overcloud_environment().get(
             'parameter_defaults', {}).get('AdminPassword')
         if admin_password:
-            ret['undercloud']['vars']['overcloud_admin_password'] =\
+            ret['Undercloud']['vars']['overcloud_admin_password'] =\
                 admin_password
         endpoint_map = self.stack_outputs.get('EndpointMap')
 
-        ret['undercloud']['vars']['undercloud_service_list'] = \
+        ret['Undercloud']['vars']['undercloud_service_list'] = \
             self.get_undercloud_service_list()
 
         if endpoint_map:
             horizon_endpoint = endpoint_map.get('HorizonPublic', {}).get('uri')
             if horizon_endpoint:
-                ret['undercloud']['vars']['overcloud_horizon_url'] =\
+                ret['Undercloud']['vars']['overcloud_horizon_url'] =\
                     horizon_endpoint
 
         role_net_ip_map = self.stack_outputs.get('RoleNetIpMap', {})
         role_node_id_map = self.stack_outputs.get('ServerIdData', {})
         networks = set()
-        role_data = self.stack_outputs.get('RoleData', {})
         role_net_hostname_map = self.stack_outputs.get(
             'RoleNetHostnameMap', {})
         children = []
         for role, hostnames in role_net_hostname_map.items():
             if hostnames:
                 names = hostnames.get(HOST_NETWORK) or []
-                shortnames = [n.split(".%s." % HOST_NETWORK)[0] for n in names]
+                shortnames = [n.split(".%s." % HOST_NETWORK)[0].lower()
+                              for n in names]
                 # Create a group per hostname to map hostname to IP
                 ips = role_net_ip_map[role][HOST_NETWORK]
+                hosts = {}
                 for idx, name in enumerate(shortnames):
-                    ret[name] = {'hosts': self._hosts([ips[idx]])}
+                    hosts[name] = {}
+                    hosts[name].update({
+                        'ansible_host': ips[idx]})
                     if 'server_ids' in role_node_id_map:
-                        ret[name]['vars'] = {
+                        hosts[name].update({
                             'deploy_server_id': role_node_id_map[
-                                'server_ids'][role][idx]}
+                                'server_ids'][role][idx]})
                     # Add variable for listing enabled networks in the node
-                    ret[name]['vars']['enabled_networks'] = \
-                        [str(net) for net in role_net_ip_map[role]]
+                    hosts[name].update({
+                        'enabled_networks':
+                            [str(net) for net in role_net_ip_map[role]]})
                     # Add variable for IP on each network
                     for net in role_net_ip_map[role]:
-                        ret[name]['vars']["%s_ip" % net] = \
-                            role_net_ip_map[role][net][idx]
-                    networks.update(ret[name]['vars']['enabled_networks'])
+                        hosts[name].update({
+                            "%s_ip" % net:
+                                role_net_ip_map[role][net][idx]})
+                    networks.update(hosts[name]['enabled_networks'])
 
                 children.append(role)
+
+                if self.hosts_format_dict:
+                    hosts_format = hosts
+                else:
+                    hosts_format = [h for h in hosts.keys()]
+                    hosts_format.sort()
+
                 ret[role] = {
-                    'children': self._hosts(sorted(shortnames)),
+                    'hosts': hosts_format,
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user,
                         'bootstrap_server_id': role_node_id_map.get(
                             'bootstrap_server_id'),
+                        # Keep "role_name" until we get rid of it
+                        # https://bugs.launchpad.net/tripleo/+bug/1771171
                         'role_name': role,
+                        'tripleo_role_name': role,
                     }
+
                 }
-                # Note we add each individual key from role_data, because if
-                # any template sections define inline ansible with j2 variables
-                # ansible silently treats those inventory variables as
-                # undefined
-                # This at least means we can consume those keys which don't
-                # have this problem (in general we don't need the nested
-                # ansible *tasks because these are available via config
-                # download already)
-                for k in role_data[role]:
-                    ret[role]['vars']["role_data_%s" % k] = role_data[role][k]
+
+                self.hostvars.update(hosts)
 
         if children:
             vip_map = self.stack_outputs.get('VipMap', {})
@@ -266,8 +276,10 @@ class TripleoInventory(object):
                     }
                 }
 
-        # Prevent Ansible from repeatedly calling us to get empty host details
-        ret['_meta'] = {'hostvars': {}}
+        if not self.hosts_format_dict:
+            # Prevent Ansible from repeatedly calling us to get empty host
+            # details
+            ret['_meta'] = {'hostvars': self.hostvars}
 
         return ret
 
