@@ -34,14 +34,14 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
 
 
 filedata = six.u("""container_images:
-- imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+- imagename: docker.io/tripleoqueens/heat-docker-agents-centos:latest
   push_destination: localhost:8787
-- imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+- imagename: docker.io/tripleoqueens/centos-binary-nova-compute:liberty
   uploader: docker
   push_destination: localhost:8787
-- imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+- imagename: docker.io/tripleoqueens/centos-binary-nova-libvirt:liberty
   uploader: docker
-- imagename: docker.io/tripleomaster/image-with-missing-tag
+- imagename: docker.io/tripleoqueens/image-with-missing-tag
   push_destination: localhost:8787
 """)
 
@@ -164,10 +164,10 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': 'docker.io/tripleomaster',
+                'namespace': 'docker.io/tripleoqueens',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.0.3-stable-3.0-luminous-centos-7-x86_64',
+                'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
                 'logging': 'files',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
@@ -179,7 +179,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
         self.assertEqual(
             {
-                'namespace': '192.0.2.0:5000/tripleomaster',
+                'namespace': '192.0.2.0:5000/tripleoqueens',
                 'ceph_namespace': 'docker.io/cephh',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
@@ -190,7 +190,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'neutron_driver': 'ovn'
             },
             builder.container_images_template_inputs(
-                namespace='192.0.2.0:5000/tripleomaster',
+                namespace='192.0.2.0:5000/tripleoqueens',
                 ceph_namespace='docker.io/cephh',
                 ceph_image='ceph-daemon',
                 ceph_tag='latest',
@@ -220,17 +220,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             tag='liberty'
         )
         container_images = [{
-            'imagename': 'docker.io/tripleomaster/'
+            'imagename': 'docker.io/tripleoqueens/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'imagename': 'docker.io/tripleomaster/'
+            'imagename': 'docker.io/tripleoqueens/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
-            'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
+            'imagename': 'docker.io/tripleoqueens/image-with-missing-tag',
             'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
@@ -273,25 +273,25 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
     def test_container_images_yaml_in_sync(self):
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-rsyslog-base:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -299,23 +299,23 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_odl(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-rsyslog-base:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -323,36 +323,36 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_ovn(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-rsyslog-base:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
 
     def test_container_images_yaml_in_sync_for_stdout_logging(self):
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'imagename': 'docker.io/tripleoqueens/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images, logging='stdout')
