@@ -101,13 +101,14 @@ class DriverInfo(object):
 class PrefixedDriverInfo(DriverInfo):
     def __init__(self, prefix, deprecated_mapping=None,
                  has_port=False, address_field='address',
-                 default_port=None):
+                 default_port=None,
+                 mandatory_fields=None):
         mapping = {
             'pm_addr': '%s_%s' % (prefix, address_field),
             'pm_user': '%s_username' % prefix,
             'pm_password': '%s_password' % prefix,
         }
-        mandatory_fields = list(mapping)
+        mandatory_fields = mandatory_fields or list(mapping)
 
         if has_port:
             mapping['pm_port'] = '%s_port' % prefix
@@ -297,7 +298,8 @@ class UcsDriverInfo(DriverInfo):
 DRIVER_INFO = {
     # production drivers
     '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True,
-                                             default_port=623),
+                                             default_port=623,
+                                             mandatory_fields=['pm_addr']),
     '(idrac|.*_drac)': PrefixedDriverInfo('drac', has_port=True),
     '(ilo|.*_ilo)': PrefixedDriverInfo('ilo', has_port=True),
     '(cisco\-ucs\-managed|.*_ucs)': UcsDriverInfo(),
@@ -451,8 +453,8 @@ _NON_DRIVER_FIELDS = {'cpu': '/properties/cpus',
                       'name': '/name',
                       'resource_class': '/resource_class',
                       'kernel_id': '/driver_info/deploy_kernel',
-                      'ramdisk_id': '/driver_info/deploy_ramdisk',
-                      'capabilities': '/properties/capabilities'}
+                      'ramdisk_id': '/driver_info/deploy_ramdisk'}
+
 
 _NON_DRIVER_FIELDS.update({field: '/%s' % field
                            for field in _KNOWN_INTERFACE_FIELDS})
@@ -471,6 +473,10 @@ def _update_or_register_ironic_node(node, node_map, client):
             if field in node:
                 patched[path] = node.pop(field)
 
+        if 'capabilities' in node:
+            patched['/properties/capabilities'] = dict_to_capabilities(
+                node.pop('capabilities'))
+
         driver_info = handler.convert(node)
         for key, value in driver_info.items():
             patched['/driver_info/%s' % key] = value
@@ -536,6 +542,10 @@ def register_all_nodes(nodes_list, client, remove=False, glance_client=None,
     return seen
 
 
+# These fields are treated specially during enrolling/updating
+_SPECIAL_NON_DRIVER_FIELDS = {'mac', 'pm_type', 'capabilities'}
+
+
 def validate_nodes(nodes_list):
     """Validate all nodes list.
 
@@ -599,7 +609,7 @@ def validate_nodes(nodes_list):
         for field in node:
             converted = handler.convert_key(field)
             if (converted is None and field not in _NON_DRIVER_FIELDS and
-                    field not in ('mac', 'pm_type')):
+                    field not in _SPECIAL_NON_DRIVER_FIELDS):
                 failures.append((index, 'Unknown field %s' % field))
 
     if failures:
@@ -609,8 +619,14 @@ def validate_nodes(nodes_list):
 
 def dict_to_capabilities(caps_dict):
     """Convert a dictionary into a string with the capabilities syntax."""
+    if isinstance(caps_dict, six.string_types):
+        return caps_dict
+
+    # NOTE(dtantsur): sort capabilities so that their order does not change
+    # between updates.
+    items = sorted(caps_dict.items(), key=lambda tpl: tpl[0])
     return ','.join(["%s:%s" % (key, value)
-                     for key, value in caps_dict.items()
+                     for key, value in items
                      if value is not None])
 
 
